/*
Copyright 2021 The Knative Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package fake

import (
	"context"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	labels "k8s.io/apimachinery/pkg/labels"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	testing "k8s.io/client-go/testing"
	v1 "knative.dev/eventing/pkg/apis/flows/v1"
)

// FakeSequences implements SequenceInterface
type FakeSequences struct {
	Fake *FakeFlowsV1
	ns   string
}

var sequencesResource = v1.SchemeGroupVersion.WithResource("sequences")

var sequencesKind = v1.SchemeGroupVersion.WithKind("Sequence")

// Get takes name of the sequence, and returns the corresponding sequence object, and an error if there is any.
func (c *FakeSequences) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.Sequence, err error) {
	emptyResult := &v1.Sequence{}
	obj, err := c.Fake.
		Invokes(testing.NewGetActionWithOptions(sequencesResource, c.ns, name, options), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Sequence), err
}

// List takes label and field selectors, and returns the list of Sequences that match those selectors.
func (c *FakeSequences) List(ctx context.Context, opts metav1.ListOptions) (result *v1.SequenceList, err error) {
	emptyResult := &v1.SequenceList{}
	obj, err := c.Fake.
		Invokes(testing.NewListActionWithOptions(sequencesResource, sequencesKind, c.ns, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}

	label, _, _ := testing.ExtractFromListOptions(opts)
	if label == nil {
		label = labels.Everything()
	}
	list := &v1.SequenceList{ListMeta: obj.(*v1.SequenceList).ListMeta}
	for _, item := range obj.(*v1.SequenceList).Items {
		if label.Matches(labels.Set(item.Labels)) {
			list.Items = append(list.Items, item)
		}
	}
	return list, err
}

// Watch returns a watch.Interface that watches the requested sequences.
func (c *FakeSequences) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	return c.Fake.
		InvokesWatch(testing.NewWatchActionWithOptions(sequencesResource, c.ns, opts))

}

// Create takes the representation of a sequence and creates it.  Returns the server's representation of the sequence, and an error, if there is any.
func (c *FakeSequences) Create(ctx context.Context, sequence *v1.Sequence, opts metav1.CreateOptions) (result *v1.Sequence, err error) {
	emptyResult := &v1.Sequence{}
	obj, err := c.Fake.
		Invokes(testing.NewCreateActionWithOptions(sequencesResource, c.ns, sequence, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Sequence), err
}

// Update takes the representation of a sequence and updates it. Returns the server's representation of the sequence, and an error, if there is any.
func (c *FakeSequences) Update(ctx context.Context, sequence *v1.Sequence, opts metav1.UpdateOptions) (result *v1.Sequence, err error) {
	emptyResult := &v1.Sequence{}
	obj, err := c.Fake.
		Invokes(testing.NewUpdateActionWithOptions(sequencesResource, c.ns, sequence, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Sequence), err
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *FakeSequences) UpdateStatus(ctx context.Context, sequence *v1.Sequence, opts metav1.UpdateOptions) (result *v1.Sequence, err error) {
	emptyResult := &v1.Sequence{}
	obj, err := c.Fake.
		Invokes(testing.NewUpdateSubresourceActionWithOptions(sequencesResource, "status", c.ns, sequence, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Sequence), err
}

// Delete takes name of the sequence and deletes it. Returns an error if one occurs.
func (c *FakeSequences) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	_, err := c.Fake.
		Invokes(testing.NewDeleteActionWithOptions(sequencesResource, c.ns, name, opts), &v1.Sequence{})

	return err
}

// DeleteCollection deletes a collection of objects.
func (c *FakeSequences) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	action := testing.NewDeleteCollectionActionWithOptions(sequencesResource, c.ns, opts, listOpts)

	_, err := c.Fake.Invokes(action, &v1.SequenceList{})
	return err
}

// Patch applies the patch and returns the patched sequence.
func (c *FakeSequences) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Sequence, err error) {
	emptyResult := &v1.Sequence{}
	obj, err := c.Fake.
		Invokes(testing.NewPatchSubresourceActionWithOptions(sequencesResource, c.ns, name, pt, data, opts, subresources...), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Sequence), err
}
